@@ -8,22 +8,19 @@ class CustomerResource(BaseResource):
         super().__init__(api_url, token, retries)
         self.resource = "customers"
 
-    def update(self, request: Union[PatchIndividualCustomerRequest, PatchBusinessCustomerRequest]) -> Union[UnitResponse[CustomerDTO], UnitError]:
+    def update(self, request: PatchCustomerRequest) -> Union[UnitResponse[CustomerDTO], UnitError]:
         payload = request.to_json_api()
         response = super().patch(f"{self.resource}/{request.customer_id}", payload)
 
-        if response.ok:
+        if super().is_20x(response.status_code):
             data = response.json().get("data")
-            if data["type"] == "individualCustomer":
-                return UnitResponse[IndividualCustomerDTO](DtoDecoder.decode(data), None)
-            else:
-                return UnitResponse[BusinessCustomerDTO](DtoDecoder.decode(data), None)
+            return UnitResponse[CustomerDTO](DtoDecoder.decode(data), None)
         else:
             return UnitError.from_json_api(response.json())
 
     def get(self, customer_id: str) -> Union[UnitResponse[CustomerDTO], UnitError]:
         response = super().get(f"{self.resource}/{customer_id}")
-        if response.status_code == 200:
+        if super().is_20x(response.status_code):
             data = response.json().get("data")
             return UnitResponse[CustomerDTO](DtoDecoder.decode(data), None)
         else:
@@ -32,7 +29,7 @@ class CustomerResource(BaseResource):
     def list(self, params: ListCustomerParams = None) -> Union[UnitResponse[List[CustomerDTO]], UnitError]:
         params = params or ListCustomerParams()
         response = super().get(self.resource, params.to_dict())
-        if response.status_code == 200:
+        if super().is_20x(response.status_code):
             data = response.json().get("data")
             return UnitResponse[CustomerDTO](DtoDecoder.decode(data), None)
         else:
@@ -46,3 +43,22 @@ class CustomerResource(BaseResource):
             return UnitResponse[CustomerDTO](DtoDecoder.decode(data), None)
         else:
             return UnitError.from_json_api(response.json())
+
+    def add_authorized_users(self, request: AddAuthorizedUsersRequest) -> Union[UnitResponse[CustomerDTO], UnitError]:
+        payload = request.to_json_api()
+        response = super().post(f"{self.resource}/{request.customer_id}/authorized-users", payload)
+        if super().is_20x(response.status_code):
+            data = response.json().get("data")
+            return UnitResponse[CustomerDTO](DtoDecoder.decode(data), None)
+        else:
+            return UnitError.from_json_api(response.json())
+
+    def remove_authorized_users(self, request: RemoveAuthorizedUsersRequest) -> Union[UnitResponse[CustomerDTO], UnitError]:
+        payload = request.to_json_api()
+        response = super().delete(f"{self.resource}/{request.customer_id}/authorized-users", payload)
+        if super().is_20x(response.status_code):
+            data = response.json().get("data")
+            return UnitResponse[CustomerDTO](DtoDecoder.decode(data), None)
+        else:
+            return UnitError.from_json_api(response.json())
+
