@@ -1,7 +1,3 @@
-import json
-from datetime import datetime, date
-from typing import Literal, Optional
-from unit.utils import date_utils
 from unit.models import *
 
 ApplicationFormStage = Literal["ChooseBusinessOrIndividual", "EnterIndividualInformation",
@@ -10,7 +6,7 @@ ApplicationFormStage = Literal["ChooseBusinessOrIndividual", "EnterIndividualInf
                                "EnterSoleProprietorshipInformation", "SoleProprietorshipApplicationCreated"]
 
 
-class ApplicationFormPrefill(object):
+class ApplicationFormPrefill(UnitDTO):
     def __init__(self, application_type: Optional[str], full_name: Optional[FullName], ssn: Optional[str],
                  passport: Optional[str], nationality: Optional[str], date_of_birth: Optional[date],
                  email: Optional[str], name: Optional[str], state_of_incorporation: Optional[str],
@@ -37,7 +33,7 @@ class ApplicationFormPrefill(object):
         self.phone = phone
 
 
-class ApplicationFormDTO(object):
+class ApplicationFormDTO(UnitDTO):
     def __init__(self, id: str, url: str, stage: ApplicationFormStage, applicant_details: ApplicationFormPrefill,
                  tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         self.id = id
@@ -54,13 +50,31 @@ class ApplicationFormDTO(object):
 AllowedApplicationTypes = Union["Individual", "Business", "SoleProprietorship"]
 
 
+class ApplicationFormSettingsOverride(UnitDTO):
+    def __init__(self, redirect_url: str, privacy_policy_url: str, electronic_disclosures_url: str,
+                 deposit_terms_url: str, client_terms_url: str, cardholder_terms_url: str, cash_advanced_terms_url: str,
+                 debit_card_disclosure_url: str, additional_disclosures: [Dict[str, str]]):
+        self.redirect_url = redirect_url
+        self.privacy_policy_url = privacy_policy_url
+        self.electronic_disclosures_url = electronic_disclosures_url
+        self.deposit_terms_url = deposit_terms_url
+        self.client_terms_url = client_terms_url
+        self.cardholder_terms_url = cardholder_terms_url
+        self.cash_advanced_terms_url = cash_advanced_terms_url
+        self.debit_card_disclosure_url = debit_card_disclosure_url
+        self.additional_disclosures = additional_disclosures
+
+
 class CreateApplicationFormRequest(UnitRequest):
     def __init__(self, tags: Optional[Dict[str, str]] = None,
                  application_details: Optional[ApplicationFormPrefill] = None,
-                 allowed_application_types: [AllowedApplicationTypes] = None):
+                 allowed_application_types: Optional[List[AllowedApplicationTypes]] = None,
+                 settings_override: Optional[ApplicationFormSettingsOverride] = None, lang: Optional[str] = None):
         self.tags = tags
         self.application_details = application_details
         self.allowed_application_types = allowed_application_types
+        self.lang = lang
+        self.settings_override = settings_override
 
     def to_json_api(self) -> Dict:
         payload = {
@@ -79,6 +93,12 @@ class CreateApplicationFormRequest(UnitRequest):
         if self.allowed_application_types:
             payload["data"]["attributes"]["allowedApplicationTypes"] = self.allowed_application_types
 
+        if self.settings_override:
+            payload["data"]["attributes"]["settingsOverride"] = self.settings_override
+
+        if self.lang:
+            payload["data"]["attributes"]["lang"] = self.lang
+
         return payload
 
     def __repr__(self):
